# [1.7.12](https://github.com/ashleney/genshin.py/compare/v1.7.11..v1.7.12) - 2025-06-01

## Bug Fixes

- Fix create release workflows not publishing to pypi - ([6470d4d](https://github.com/ashleney/genshin.py/commit/6470d4d0f0ea75e48fb86fcd2ab1ab9405a41121))

## Documentation

- Update project description in README - ([51648b0](https://github.com/ashleney/genshin.py/commit/51648b0faba6b51dc77782551ea037f435bbc7ee))
- Adjust requirements in README - ([9ede8b4](https://github.com/ashleney/genshin.py/commit/9ede8b420a6d23188bef816d36ab73e1d2133bb0))
- Add dev version install instructions to README - ([ab1f643](https://github.com/ashleney/genshin.py/commit/ab1f6437233594fda2158af35c7e9bb21c8021d1))
- Fix example - ([37d6a31](https://github.com/ashleney/genshin.py/commit/37d6a31be54725d89b2e93134b8a796060712824))
- Match the content in README with index.md - ([5523b97](https://github.com/ashleney/genshin.py/commit/5523b9788b6d467dd9cfa9afbb797659208f7cde))

## Features

- Add chronicled_banners field to GenshinEventCalendar - ([3349a79](https://github.com/ashleney/genshin.py/commit/3349a794a17bbba058f163c880d95f2977eaaba3))
- Add support for getting Envisaged Echoes - ([c2314ad](https://github.com/ashleney/genshin.py/commit/c2314adcb88fe25fbf01551ea8dbe70cb8a2791f))

## Improvements

- Make uid param optional in genshin chronicle methods - ([c3cdae4](https://github.com/ashleney/genshin.py/commit/c3cdae43b28ed41def895a088b32a193f2759faa))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#252](https://github.com/ashleney/genshin.py/issues/252)) - ([9019b09](https://github.com/ashleney/genshin.py/commit/9019b092dad372c1000c5b1016ca4f863824cebf))

## Style

- Reformat code - ([beed69b](https://github.com/ashleney/genshin.py/commit/beed69bbc41a51ec1e4144f0d8f5eb363922caa1))

## Tests

- Add envisaged echoes test - ([463b829](https://github.com/ashleney/genshin.py/commit/463b829f7de1005e423d1f36f0b48f135c3f062b))

